summaryrefslogtreecommitdiffstats
path: root/libtdegames/kcarddialog.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:32:59 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:32:59 -0600
commit2f84d0e2d3d4252e6aee24aceafa45dbdb7f4d1d (patch)
treeea24a96bad3bb7356ec1a2dca2a1338692d79745 /libtdegames/kcarddialog.h
parentd6f3812c8d969a673b420beca2482804177704fb (diff)
downloadtdegames-2f84d0e2d3d4252e6aee24aceafa45dbdb7f4d1d.tar.gz
tdegames-2f84d0e2d3d4252e6aee24aceafa45dbdb7f4d1d.zip
Rename KCModule, KConfig, KIO, KServer, and KSocket to avoid conflicts with KDE4
Diffstat (limited to 'libtdegames/kcarddialog.h')
-rw-r--r--libtdegames/kcarddialog.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/libtdegames/kcarddialog.h b/libtdegames/kcarddialog.h
index 58bc3d34..b80e87cd 100644
--- a/libtdegames/kcarddialog.h
+++ b/libtdegames/kcarddialog.h
@@ -26,7 +26,7 @@
#include <kdemacros.h>
class TQIconViewItem;
-class KConfig;
+class TDEConfig;
class KCardDialogPrivate;
@@ -63,7 +63,7 @@ class KCardDialogPrivate;
* deck/carddir. You have to save the value of those parameters in your config
* file - that's why the parameters are needed.
*
* You can also provide a KConfig pointer (usually kapp->config()). This
* pointer is used to store information about the dialog in an own group
* ("KCardDailog").
* So you can just ignore the randomCardDir and randomDeck
@@ -156,7 +156,7 @@ public:
*/
static int getCardDeck(TQString &deck,TQString &carddir, TQWidget *parent=0,
CardFlags flags=Both, bool* randomDeck=0,
- bool* randomCardDir=0, double* scale=0, KConfig* conf=0);
+ bool* randomCardDir=0, double* scale=0, TDEConfig* conf=0);
/**
* Read the configuration from the applications rc file and put the
@@ -173,7 +173,7 @@ public:
* random cardDir if this is desired according to the config)
* @param scale The scaling factor (usually 1)
**/
- static void getConfigCardDeck(KConfig* conf, TQString& deck, TQString& cardDir, double& scale);
+ static void getConfigCardDeck(TDEConfig* conf, TQString& deck, TQString& cardDir, double& scale);
/**
* Returns the default path to the card deck backsides. You want
@@ -301,7 +301,7 @@ public:
* Load the default settings into the dialog (e.g. whether the "use random
* deck" checkbox is checked or not).
**/
- void loadConfig(KConfig* conf);
+ void loadConfig(TDEConfig* conf);
/**
* Saves the KCardDialog config into a config file. This should be the
@@ -309,7 +309,7 @@ public:
* ("KCardDialog"). These settings are used by @ref loadConfig and @ref
* getConfigCardDeck.
**/
- void saveConfig(KConfig* conf);
+ void saveConfig(TDEConfig* conf);
protected:
@@ -63,7 +63,7 @@ class KCardDialogPrivate;
* file - that's why the parameters are needed.
*
- * You can also provide a KConfig pointer (usually kapp->config()). This
+ * You can also provide a TDEConfig pointer (usually kapp->config()). This
* pointer is used to store information about the dialog in an own group
* ("KCardDailog").